@@ -17,9 +17,9 @@ plotabn <- function(...) {
 
 
 plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
-                    fitted.values=NULL, digits=2, edge.strength=NULL,
-                    edge.direction="pc", edge.color="black", edge.arrowsize=0.5, edge.fontsize=5,
-                    node.fontsize=10, node.fillcolor=c("lightblue","brown3","chartreuse3"),
+                    fitted.values=NULL, digits=2, edge.strength=NULL, edge.strength.lwd=5,
+                    edge.direction="pc", edge.color="black", edge.linetype="solid", edge.arrowsize=0.6, edge.fontsize=node.fontsize,
+                    node.fontsize=12, node.fillcolor=c("lightblue","brown3","chartreuse3"),
                     node.fillcolor.list=NULL, node.shape=c("circle","box","ellipse","diamond"),
                     plot=TRUE , ... )       {
 
@@ -34,6 +34,11 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
         data.dists <- dag$score.cache$data.dists;
         dag <- dag$dag
     }
+  if(inherits(x=dag, what="abnFit")){
+    data.dists <- dag$abnDag$data.dists
+    dag <- dag$abnDag$dag
+  }
+  if (is.null(data.dists)) stop("'data.dist' need to be provided.")
     name <- names(data.dists)
 
 
@@ -45,22 +50,22 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
             ## consistency checks
             diag(dag) <- 0
             dag[dag > 0] <- 1
-            dag <- check.valid.dag(dag.m=dag, is.ban.matrix=FALSE, group.var=NULL)
 
             ## naming
-            if (is.null(colnames(dag))) {
+            if (is.null(rownames(dag))) {
                 colnames(dag) <- name
                 rownames(dag) <- name
             }
+            dag <- check.valid.dag(dag=dag, is.ban.matrix=FALSE, group.var=NULL)
         } else {
             if (grepl("~", as.character(dag)[1], fixed=T)) {
                 dag <- formula.abn(f=dag, name=name)
                 ## run a series of checks on the DAG passed
-                dag <- check.valid.dag(dag.m=dag, is.ban.matrix=FALSE, group.var=NULL)
+                dag <- check.valid.dag(dag=dag, is.ban.matrix=FALSE, group.var=NULL)
             }
         }
     } else {
-        stop("Dag specification must either be a matrix or a formula expression")
+        stop("'dag' specification must either be a matrix or a formula expression")
     }
 
     # contains Rgraphviz
@@ -69,12 +74,14 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
         dag[dag != 0] <- 1     # this should not be necessary!
     }
 
+
     ## create an object graph
     am.graph <- new(Class="graphAM", adjMat=dag,
                     edgemode=ifelse(edge.direction=="undirected","undirected","directed"))
 
     ## ========= SHAPE =========
-    ## Shape: plot differentially depending on the distribution
+    ## Shape: plot differential depending on the distribution
+    node.shape <- rep(node.shape, 4)
     shape <- rep(node.shape[1], length(data.dists) )
     shape[data.dists == "binomial"] <- node.shape[2]
     shape[data.dists == "poisson"] <- node.shape[3]
@@ -103,7 +110,7 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
     ## Plot the fitted values in abn as edges label
 #    print(names.edges)
     if (!is.null(fitted.values)) {
-        space <- "      "
+        space <- "   "
         edge.label <- c()
         for (i in 1:length(fitted.values)) {
             if ((length(fitted.values[[i]]) > 1)& (data.dists[names(fitted.values)[i]] != "gaussian")) {
@@ -120,7 +127,8 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
 
     ## =================== Arc Strength ===================
     ## Arc strength: plot the AS of the dag arcs
-    if (is.matrix(edge.strength) & (edge.direction != "undirected")) {
+#    if (is.matrix(edge.strength) & (edge.direction != "undirected")) {
+    if (is.matrix(edge.strength)) {
         if (any(edge.strength<0)) stop("'edge.strength' should be positive")
         if (any(edge.strength[dag ==0] >0)) stop("'edge.strength' does not match dag")
         min.as <- min(edge.strength[edge.strength > 0])
@@ -132,7 +140,7 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
         for (i in 1:length(dag[1, ])) {
             for (j in 1:length(dag[1, ])) {
                 if (dag[i, j] == 1) {
-                    edge.lwd <- cbind(edge.lwd, round(10 * edge.strength.norm[i, j]) + 1)
+                    edge.lwd <- cbind(edge.lwd, round(edge.strength.lwd * edge.strength.norm[i, j]) + 1)
                 }
             }
         }
@@ -142,30 +150,35 @@ plotAbn <- function(dag, data.dists=NULL, markov.blanket.node=NULL,
     class(edge.lwd) <- "character"
     names(edge.lwd) <- names.edges
 
-
     ## ====== Plot ======
     attrs <- list(graph=list(rankdir="BT"),
                   node=list(fontsize=node.fontsize, fixedsize=FALSE),
-                  edge=list(arrowsize=edge.arrowsize, color=edge.color, fontsize=edge.fontsize))
+                  edge=list(arrowsize=edge.arrowsize, color=edge.color, lty=edge.linetype, fontsize=edge.fontsize))
     nodeAttrs <- list(fillcolor=fillcolor, shape=shape)
-    edgeAttrs <- list(label=edge.label, lwd=edge.lwd)#, dir=dir)
+    edgeAttrs <- list(label=edge.label, lwd=edge.lwd)
 #     print(edgeAttrs)
-    if (all(shape %in% c("circle","box","ellipse")))  {
-        if (edge.direction == "pc")  {     # specify approporiate direction!
-            dir <- rep("back", length(names.edges))
-            names(dir) <- names.edges
-            edgeAttrs <- c(edgeAttrs, list(dir=dir))
-        }
-        if (plot)  am.graph <- Rgraphviz::plot(am.graph,
-                                               attrs=attrs, nodeAttrs=nodeAttrs, edgeAttrs=edgeAttrs, ...)
-    } else {
-        am.graph <- layoutGraph(am.graph, attrs=attrs, nodeAttrs=nodeAttrs, edgeAttrs=edgeAttrs)
+#    if (all(shape %in% c("circle","box","ellipse")))  {
+    am.graph <- layoutGraph(am.graph, attrs=attrs, nodeAttrs=nodeAttrs, edgeAttrs=edgeAttrs)
+
+    if (edge.direction == "pc")  {     # specify appropriate direction!
+      edgeRenderInfo(am.graph) <- list(arrowtail="open")
+      edgeRenderInfo(am.graph) <- list(arrowhead="none")
+#      edgeRenderInfo(am.graph) <- list(direction=NULL)# MESSES up!!! not needed.
+    }
+    edgeRenderInfo(am.graph) <- list(lwd=edge.lwd)
+
+  #  if (plot) renderGraph(am.graph, attrs=attrs, nodeAttrs=nodeAttrs, edgeAttrs=edgeAttrs)
+    if (plot) renderGraph(am.graph, ...)
+
+#   } else {
+#        am.graph <- layoutGraph(am.graph, attrs=attrs, nodeAttrs=nodeAttrs, edgeAttrs=edgeAttrs, ...)
         # the following does not work in R
 #        edgeRenderInfo(am.graph)[["direction"]] <- "back"
         # hence
-        warning("edge.direction='pc' is not working with diamond shapes.")
-        if (plot) renderGraph(am.graph, ...)
-    }
+#        warning("edge.direction='pc' is not working with diamond shapes.")
+#        edgeRenderInfo(am.graph) <- list(lwd=edge.lwd)
+#        if (plot) renderGraph(am.graph,attrs=attrs, nodeAttrs=nodeAttrs, edgeAttrs=edgeAttrs)
+#    }
 
     invisible(am.graph)
 }  #EOF
